# Generated by Django 2.1.1 on 2018-09-08 22:49

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('main', '0004_musician_active'),
    ]

    operations = [
        migrations.AlterField(
            model_name='musician',
            name='instrument',
            field=models.CharField(choices=[('GUITAR', 'Guitar'), ('VOICE', 'Voice'), ('DRUM', 'Drum'), ('SAX', 'Saxophone')], max_length=100),
        ),
    ]



import django
from django.contrib.admin.utils import display_for_field as django_display_for_field


if django.VERSION >= (1, 9):
    def get_empty_value_display(model_admin):
        return model_admin.get_empty_value_display()

    display_for_field = django_display_for_field
else:
    def get_empty_value_display(model_admin):
        from django.contrib.admin.views.main import EMPTY_CHANGELIST_VALUE
        return EMPTY_CHANGELIST_VALUE

    def display_for_field(value, field, empty_value_display):
        if value is None:
            return empty_value_display
        else:
            return django_display_for_field(value, field)
